Module silk::entry
[−]
[src]
Structs
| Entry |
Functions
| create_entry |
Creates the next Entry 'num_hashes' after 'start_hash'. |
| create_entry_mut |
Creates the next Tick Entry 'num_hashes' after 'start_hash'. |
| next_hash |
Creates the hash 'num_hashes' after start_hash. If the event contains signature, the final hash will be a hash of both the previous ID and the signature. |
| next_tick |
Creates the next Tick Entry 'num_hashes' after 'start_hash'. |