pub struct EdgeTypeDef {
pub description: Option<String>,
pub source_types: Vec<String>,
pub target_types: Vec<String>,
pub properties: BTreeMap<String, PropertyDef>,
}Expand description
Definition of an edge type in the ontology.
Fields
description: Option<String>source_types: Vec<String>Which node types can be the source of this edge.
target_types: Vec<String>Which node types can be the target of this edge.
properties: BTreeMap<String, PropertyDef>Trait Implementations
Sourceimpl Clone for EdgeTypeDef
impl Clone for EdgeTypeDef
Sourcefn clone(&self) -> EdgeTypeDef
fn clone(&self) -> EdgeTypeDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EdgeTypeDef
impl Debug for EdgeTypeDef
Sourceimpl<'de> Deserialize<'de> for EdgeTypeDef
impl<'de> Deserialize<'de> for EdgeTypeDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EdgeTypeDef
impl PartialEq for EdgeTypeDef
Sourceimpl Serialize for EdgeTypeDef
impl Serialize for EdgeTypeDef
impl StructuralPartialEq for EdgeTypeDef